"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.build = void 0;
const child_process_1 = require("child_process");
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const _1 = require(".");
let _builtWorkspaces = false, _builtBinaries = false;
/**
 * Build with `cargo-zigbuild zigbuild`
 */
function build(options) {
    try {
        let outputName;
        let shouldCompile;
        let extra_args;
        let targetReleaseDir = path.join(options.entry, 'target', options.target, 'release');
        // Build binary
        if (options.bin) {
            outputName = options.bin;
            if (_builtBinaries) {
                shouldCompile = false;
                extra_args = undefined;
            }
            else if (_1.Settings.BUILD_INDIVIDUALLY) {
                shouldCompile = true;
                extra_args = ['--bin', outputName];
            }
            else {
                _builtBinaries = true;
                shouldCompile = true;
                extra_args = ['--bins'];
            }
        }
        // Build package - i.e. workspace member
        else {
            outputName = options.package;
            if (_builtWorkspaces) {
                shouldCompile = false;
                extra_args = undefined;
            }
            else if (_1.Settings.BUILD_INDIVIDUALLY) {
                shouldCompile = true;
                extra_args = ['--package', outputName];
            }
            else {
                _builtWorkspaces = true;
                shouldCompile = true;
                extra_args = ['--workspace'];
            }
        }
        if (shouldCompile) {
            // Check if directory `./target/{{target}}/release` exists
            const releaseDirExists = fs.existsSync(targetReleaseDir);
            // Base arguments for `cargo-zigbuild`
            const buildArgs = ['--quiet', '--color', 'always'];
            let extraBuildArgs = options.extraBuildArgs || _1.Settings.EXTRA_BUILD_ARGS;
            let features = options.features || _1.Settings.FEATURES;
            if (extraBuildArgs) {
                buildArgs.push(...extraBuildArgs);
            }
            if (features) {
                buildArgs.push('--features', features.join(','));
            }
            // Set process environment (optional)
            let inputEnv = options.buildEnvironment ||
                _1.Settings.BUILD_ENVIRONMENT;
            const buildEnv = inputEnv
                ? {
                    ...process.env,
                    ...inputEnv,
                }
                : undefined;
            if (releaseDirExists) {
                console.log(`🍺  Building Rust code...`);
            }
            else {
                // The `release` directory doesn't exist for the specified
                // target. This is most likely an initial run, so `cargo-zigbuild`
                // will take much longer than usual to cross-compile the code.
                //
                // Print out an informative message that the `build` step is
                // expected to take longer than usual.
                console.log(`🍺  Building Rust code with \`cargo-zigbuild\`. This may take a few minutes...`);
            }
            const args = [
                'zigbuild',
                '--release',
                '--target',
                options.target,
                ...buildArgs,
                ...extra_args,
            ];
            const zigBuild = (0, child_process_1.spawnSync)('cargo-zigbuild', args, {
                cwd: options.entry,
                env: buildEnv,
            });
            if (zigBuild.status !== 0) {
                console.error(zigBuild.stderr.toString().trim());
                console.error(`💥  Run \`cargo zigbuild\` errored.`);
                process.exit(1);
                // Note: I don't want to raise an error here, as that will clutter the
                // output with the stack trace here. But maybe, there's a way to
                // suppress that?
                // throw new Error(zigBuild.stderr.toString().trim());
            }
        }
        let from = path.join(targetReleaseDir, outputName);
        let to = path.join(options.outDir, 'bootstrap');
        fs.copyFileSync(from, to);
    }
    catch (err) {
        throw new Error(`Failed to build file at ${options.entry}: ${err}`);
    }
}
exports.build = build;
