"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RustFunction = void 0;
const lambda = __importStar(require("aws-cdk-lib/aws-lambda"));
const crypto = __importStar(require("crypto"));
const path = __importStar(require("path"));
const perf_hooks_1 = require("perf_hooks");
const _1 = require(".");
const build_1 = require("./build");
const utils_1 = require("./utils");
/**
 * A Rust Lambda function built using `cargo-zigbuild`
 */
class RustFunction extends lambda.Function {
    constructor(scope, id, props) {
        const entry = props.directory || _1.Settings.ENTRY;
        const handler = 'does.not.matter';
        const target = props.target || _1.Settings.TARGET;
        const arch = props.architecture || (0, utils_1.lambdaArchitecture)(target);
        const buildDir = props.buildDir || _1.Settings.BUILD_DIR;
        let executable;
        let binName;
        if (props.package) {
            binName = undefined;
            executable = props.package;
        }
        else {
            binName = props.bin || (0, utils_1.getPackageName)(entry);
            executable = binName;
        }
        const handlerDir = path.join(buildDir, 
        // We need to generate a *unique* hash in case there are multiple
        // executables, so use the `binName` here instead.
        crypto
            .createHash('sha256')
            .update(executable)
            .digest('hex'));
        (0, utils_1.createDirectory)(buildDir);
        (0, utils_1.createDirectory)(handlerDir);
        let start = perf_hooks_1.performance.now();
        // Build with `cargo-zigbuild`
        (0, build_1.build)({
            ...props,
            entry,
            bin: binName,
            target: target,
            outDir: handlerDir,
        });
        (0, utils_1.logTime)(start, `🎯  Cross-compile \`${executable}\``);
        let lambdaEnv = props.environment;
        // Sets up logging if needed.
        //   Ref: https://rust-lang-nursery.github.io/rust-cookbook/development_tools/debugging/config_log.html
        if (props.setupLogging) {
            lambdaEnv = lambdaEnv || {};
            // Need to use the *underscore*- separated variant, which is
            // coincidentally how Rust imports are done.
            let underscoredName = executable.split('-').join('_');
            // Set the `RUST_LOG` environment variable.
            lambdaEnv.RUST_LOG = `${_1.Settings.DEFAULT_LOG_LEVEL},${underscoredName}=${_1.Settings.MODULE_LOG_LEVEL}`;
        }
        super(scope, id, {
            ...props,
            runtime: _1.Settings.RUNTIME,
            architecture: arch,
            code: lambda.Code.fromAsset(handlerDir),
            handler: handler,
            environment: lambdaEnv,
        });
    }
}
exports.RustFunction = RustFunction;
